@@ -6,7 +6,7 @@ use vars qw(@ISA $VERSION);
 use DynaLoader;
 
 BEGIN {
-    $VERSION = '4.11';
+    $VERSION = '4.12';
     @ISA     = qw(DynaLoader);
     __PACKAGE__->bootstrap;
 }
@@ -169,6 +169,26 @@ This is how you enable sharing for a specific WWW::Curl::Easy handle:
 	$curl->setopt(CURLOPT_SHARE, $curlsh)
 		Attach share object to WWW::Curl::Easy instance
 
+=head1 WWW::Curl::Form
+
+    use WWW::Curl::Form;
+    my $curlf = WWW::Curl::Form->new;
+    $curlf->curl_formaddfile($filename, 'attachment', "multipart/form-data");
+    $curlf->curl_formadd("FIELDNAME", "VALUE");
+
+    $curl->setopt(CURLOPT_HTTPPOST, $curlf);
+
+Its usable methods are:
+
+    $curlf = new WWW::Curl::Form
+        This method constructs a new WWW::Curl::Form object.
+
+    $curlf->formadd(FIELDNAME, VALUE)
+        This method adds a field with a given value, to the form that is being submitted.
+
+    $curlf->formaddfile(FILENAME, DESCRIPTION, TYPE)
+        This method will add a file to the form. The description is the name of the field
+        that you form expects the data to be submitted in.
 
 =head1 COMPATIBILITY
 
@@ -217,7 +237,11 @@ Not implemented and won't be as this method is considered deprecated.
 
 =item curl_formadd
 
-Not yet implemented.
+Seems to be working.
+
+=item curl_formaddfile
+
+Seems to be working.
 
 =item curl_formfree
 
@@ -340,7 +364,7 @@ repackaged the module into a more modern form.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000-2005,2008,2009 Daniel Stenberg, Cris Bailiff,
+Copyright (C) 2000-2005,2008-2010 Daniel Stenberg, Cris Bailiff,
 Sebastian Riedel, Balint Szilakszi et al.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
